# ezsave

*ezsave* is a simple package to save python lists, dictionaries and strings to a file.

By default it saves a temporary file so your files don't get corrupted if your program or computer crashes.